@@ -4,10 +4,12 @@ import requests
 def get(url: str, headers: dict) -> str:
     response = requests.get(url, headers=headers)
 
-    response_content = response.content.decode('UTF-8')
+    response_content: str = response.content.decode("UTF-8")
 
     if response.status_code != 200:
-        raise Exception(f"Client failed to fetch.  Response/Error message: {response_content}")
+        raise Exception(
+            f"Client failed to fetch.  Response/Error message: {response_content}"
+        )
 
     return response_content
 
@@ -15,9 +17,11 @@ def get(url: str, headers: dict) -> str:
 def post(url: str, headers: dict, body) -> str:
     response = requests.post(url, headers=headers, data=body)
 
-    response_content = response.content.decode('UTF-8')
+    response_content: str = response.content.decode("UTF-8")
 
     if response.status_code != 200:
-        raise Exception(f"Client failed to fetch.  Response/Error message: {response_content}")
+        raise Exception(
+            f"Client failed to fetch.  Response/Error message: {response_content}"
+        )
 
     return response_content
